<center><font size=7><b>ZYJ's own python tools.</b></font></center>

Version 1.0 Official Release

This is a collection of Python tools I have written for my own work.
I have decided to publish it as a package on PyPI and GitHub so that it can be installed and used in any of my projects.
These tools are currently mainly used for data processing, data analysis, and data visualization.
It will continue to be updated in the future.

update.py may have to run under admin permission. It can run in a cmd terminal or in a python environment with admin permission.